OtpGateway class

An otp auth type the user can pick from in the manual otp flow.

Constructors

OtpGateway(Map obj)

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
The name of this auth type, to be shown to the user.
final
number int
The identifier of this auth type, to be passed to OtpGatewayPromise.pick.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited