OtpMagicRedirect enum

Controls which WhatsApp app is used when redirecting for the OtpAuthType.magicOtp and OtpAuthType.magicLink auth types.

Inheritance
Available extensions

Values

auto → const OtpMagicRedirect

Automatically selects WhatsApp or WhatsApp Business.

whatsappNormal → const OtpMagicRedirect

Always redirects to WhatsApp.

whatsappBusiness → const OtpMagicRedirect

Always redirects to WhatsApp Business.

manual → const OtpMagicRedirect

Shows a dialog letting the user choose which WhatsApp app to use when both WhatsApp and WhatsApp Business are installed.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
nativeName String
The value as the native SDKs name it.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<OtpMagicRedirect>
A constant List of the values in this enum, in order of their declaration.