OtpSettings class

Constructors

OtpSettings()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

forgetPassword(String phone, {Map<String, String>? additionalInfo, OtpMagicRedirect magicRedirect = OtpMagicRedirect.auto}) Future<OtpPromise>
Requests an otp for a forgotten password flow.
login(String phone, {Map<String, String>? additionalInfo, OtpMagicRedirect magicRedirect = OtpMagicRedirect.auto}) Future<OtpPromise>
Requests an otp for a login attempt.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register(String phone, {Map<String, String>? additionalInfo, OtpMagicRedirect magicRedirect = OtpMagicRedirect.auto}) Future<OtpPromise>
Requests an otp for a registration attempt.
toString() String
A string representation of this object.
inherited
transaction(String phone, {Map<String, String>? additionalInfo, OtpMagicRedirect magicRedirect = OtpMagicRedirect.auto}) Future<OtpPromise>
Requests an otp for a transaction.

Operators

operator ==(Object other) bool
The equality operator.
inherited